## v0.1.3 (2026-01-17)

### Fix

- **bootstrap**: resolve command execution bug
- **scripts**: use isolated venvs for multi-version testing
- **scripts**: use UV_PUBLISH_TOKEN for PyPI publish

## v0.1.2 (2025-12-29)

### Feat

- **init**: add git init and edge case tests
- **dev**: add commitizen for commit validation

### Fix

- **config**: correct commitizen tag_format to match existing tags
- **init**: remove [build-system] from root workspace template

## v0.1.1 (2025-12-28)
